@@ -2,12 +2,14 @@ from .concatenate import CutConcatenate, concat_cuts
 from .extra_padding import ExtraPadding
 from .mix import CutMix
 from .perturb_speed import PerturbSpeed
+from .perturb_tempo import PerturbTempo
 from .perturb_volume import PerturbVolume
 
 __all__ = [
-    'CutConcatenate',
-    'CutMix',
-    'ExtraPadding',
-    'PerturbSpeed',
-    'PerturbVolume'
+    "CutConcatenate",
+    "CutMix",
+    "ExtraPadding",
+    "PerturbSpeed",
+    "PerturbTempo",
+    "PerturbVolume",
 ]
