@@ -1,11 +1,15 @@
+from .adept import download_adept, prepare_adept
 from .aishell import download_aishell, prepare_aishell
+from .aishell4 import download_aishell4, prepare_aishell4
 from .ami import download_ami, prepare_ami
 from .babel import prepare_single_babel_language
 from .broadcast_news import prepare_broadcast_news
 from .callhome_egyptian import prepare_callhome_egyptian
 from .callhome_english import prepare_callhome_english
 from .cmu_arctic import download_cmu_arctic, prepare_cmu_arctic
+from .cmu_indic import download_cmu_indic, prepare_cmu_indic
 from .cmu_kids import prepare_cmu_kids
+from .commonvoice import prepare_commonvoice
 from .cslu_kids import prepare_cslu_kids
 from .dihard3 import prepare_dihard3
 from .fisher_english import prepare_fisher_english
@@ -14,7 +18,9 @@ from .gale_arabic import prepare_gale_arabic
 from .gale_mandarin import prepare_gale_mandarin
 from .gigaspeech import prepare_gigaspeech
 from .heroico import download_heroico, prepare_heroico
+from .hifitts import download_hifitts, prepare_hifitts
 from .l2_arctic import prepare_l2_arctic
+from .libricss import download_libricss, prepare_libricss
 from .librimix import download_librimix, prepare_librimix
 from .librispeech import download_librispeech, prepare_librispeech
 from .libritts import download_libritts, prepare_libritts
