@@ -3,6 +3,7 @@
 # Copyright 2021 Xiaomi Corporation (Author: Mingshuang Luo)
 # Apache 2.0
 
+import glob
 import logging
 import zipfile
 from collections import defaultdict
@@ -51,7 +52,6 @@ def download_timit(
 
 def prepare_timit(
     corpus_dir: Pathlike,
-    splits_dir: Pathlike,
     output_dir: Optional[Pathlike] = None,
     num_phones: int = 48,
     num_jobs: int = 1,
@@ -59,7 +59,6 @@ def prepare_timit(
     """
     Returns the manifests which consists of the Recodings and Supervisions.
     :param corpus_dir: Pathlike, the path of the data dir.
-    :param splits_dir: Pathlike, the path of the txt files for data division (train, dev, tst).
     :param output_dir: Pathlike, the path where to write and save the manifests.
     :param num_phones: int=48, the number of phones (60, 48 or 39) for modeling and 48 is regarded as the default value.
     :return: a Dict whose key is the dataset part, and the value is Dicts with the keys 'audio' and 'supervisions'.
@@ -67,9 +66,6 @@ def prepare_timit(
     corpus_dir = Path(corpus_dir)
     assert corpus_dir.is_dir(), f"No such directory: {corpus_dir}"
 
-    splits_dir = Path(splits_dir)
-    assert splits_dir.is_dir(), f"No such directory: {splits_dir}"
-
     if output_dir is not None:
         output_dir = Path(output_dir)
         output_dir.mkdir(parents=True, exist_ok=True)
@@ -84,78 +80,91 @@ def prepare_timit(
     else:
         raise ValueError("The value of num_phones must be in [60, 48, 39].")
 
+    dev_spks, test_spks = get_speakers()
+
     with ThreadPoolExecutor(num_jobs) as ex:
         for part in dataset_parts:
-            file_name = ""
+            wav_files = []
 
             if part == "TRAIN":
-                file_name = splits_dir / "train_samples.txt"
+                print("starting....")
+                wav_files = glob.glob(str(corpus_dir) + "/TRAIN/*/*/*.WAV")
+                # filter the SA (dialect sentences)
+                wav_files = list(
+                    filter(lambda x: x.split("/")[-1][:2] != "SA", wav_files)
+                )
             elif part == "DEV":
-                file_name = splits_dir / "dev_samples.txt"
+                wav_files = glob.glob(str(corpus_dir) + "/TEST/*/*/*.WAV")
+                # filter the SA (dialect sentences)
+                wav_files = list(
+                    filter(lambda x: x.split("/")[-1][:2] != "SA", wav_files)
+                )
+                wav_files = list(
+                    filter(lambda x: x.split("/")[-2].lower() in dev_spks, wav_files)
+                )
             else:
-                file_name = splits_dir / "tst_samples.txt"
-            wav_files = []
-            with open(file_name, "r") as f:
-                lines = f.readlines()
-                for line in lines:
-                    items = line.strip().split(" ")
-                    wav = corpus_dir / items[-1]
-                    wav_files.append(wav)
-                logging.debug(f"{part} dataset manifest generation.")
-                recordings = []
-                supervisions = []
+                wav_files = glob.glob(str(corpus_dir) + "/TEST/*/*/*.WAV")
+                # filter the SA (dialect sentences)
+                wav_files = list(
+                    filter(lambda x: x.split("/")[-1][:2] != "SA", wav_files)
+                )
+                wav_files = list(
+                    filter(lambda x: x.split("/")[-2].lower() in test_spks, wav_files)
+                )
 
-                for wav_file in tqdm(wav_files):
-                    items = str(wav_file).strip().split("/")
-                    idx = items[-2] + "-" + items[-1][:-4]
-                    speaker = items[-2]
-                    transcript_file = Path(wav_file).with_suffix(".PHN")
-                    if not Path(wav_file).is_file():
-                        logging.warning(f"No such file: {wav_file}")
-                        continue
-                    if not Path(transcript_file).is_file():
-                        logging.warning(f"No transcript: {transcript_file}")
-                        continue
-                    text = []
-                    with open(transcript_file, "r") as f:
-                        lines = f.readlines()
-                        for line in lines:
-                            phone = line.rstrip("\n").split(" ")[-1]
-                            if num_phones != 60:
-                                phone = phones_dict[str(phone)]
-                            text.append(phone)
+            logging.debug(f"{part} dataset manifest generation.")
+            recordings = []
+            supervisions = []
 
-                        text = " ".join(text).replace("h#", "sil")
+            for wav_file in tqdm(wav_files):
+                items = str(wav_file).strip().split("/")
+                idx = items[-2] + "-" + items[-1][:-4]
+                speaker = items[-2]
+                transcript_file = Path(wav_file).with_suffix(".PHN")
+                if not Path(wav_file).is_file():
+                    logging.warning(f"No such file: {wav_file}")
+                    continue
+                if not Path(transcript_file).is_file():
+                    logging.warning(f"No transcript: {transcript_file}")
+                    continue
+                text = []
+                with open(transcript_file, "r") as f:
+                    lines = f.readlines()
+                    for line in lines:
+                        phone = line.rstrip("\n").split(" ")[-1]
+                        if num_phones != 60:
+                            phone = phones_dict[str(phone)]
+                        text.append(phone)
 
-                    recording = Recording.from_file(path=wav_file, recording_id=idx)
-                    recordings.append(recording)
-                    segment = SupervisionSegment(
-                        id=idx,
-                        recording_id=idx,
-                        start=0.0,
-                        duration=recording.duration,
-                        channel=0,
-                        language="English",
-                        speaker=speaker,
-                        text=text.strip(),
-                    )
+                    text = " ".join(text).replace("h#", "sil")
 
-                    supervisions.append(segment)
+                recording = Recording.from_file(path=wav_file, recording_id=idx)
+                recordings.append(recording)
+                segment = SupervisionSegment(
+                    id=idx,
+                    recording_id=idx,
+                    start=0.0,
+                    duration=recording.duration,
+                    channel=0,
+                    language="English",
+                    speaker=speaker,
+                    text=text.strip(),
+                )
 
-                    recording_set = RecordingSet.from_recordings(recordings)
-                    supervision_set = SupervisionSet.from_segments(supervisions)
-                    validate_recordings_and_supervisions(recording_set, supervision_set)
+                supervisions.append(segment)
 
-                    if output_dir is not None:
-                        supervision_set.to_json(
-                            output_dir / f"supervisions_{part}.json"
-                        )
-                        recording_set.to_json(output_dir / f"recordings_{part}.json")
+                recording_set = RecordingSet.from_recordings(recordings)
+                supervision_set = SupervisionSet.from_segments(supervisions)
+                validate_recordings_and_supervisions(recording_set, supervision_set)
 
-                    manifests[part] = {
-                        "recordings": recording_set,
-                        "supervisions": supervision_set,
-                    }
+                if output_dir is not None:
+                    supervision_set.to_json(output_dir / f"supervisions_{part}.json")
+                    recording_set.to_json(output_dir / f"recordings_{part}.json")
+
+                manifests[part] = {
+                    "recordings": recording_set,
+                    "supervisions": supervision_set,
+                }
 
     return manifests
 
@@ -303,3 +312,90 @@ def get_phonemes(num_phones):
         logging.debug("Using 60 phones for modeling!")
 
     return phonemes
+
+
+def get_speakers():
+
+    # List of test speakers
+    test_spk = [
+        "fdhc0",
+        "felc0",
+        "fjlm0",
+        "fmgd0",
+        "fmld0",
+        "fnlp0",
+        "fpas0",
+        "fpkt0",
+        "mbpm0",
+        "mcmj0",
+        "mdab0",
+        "mgrt0",
+        "mjdh0",
+        "mjln0",
+        "mjmp0",
+        "mklt0",
+        "mlll0",
+        "mlnt0",
+        "mnjm0",
+        "mpam0",
+        "mtas1",
+        "mtls0",
+        "mwbt0",
+        "mwew0",
+    ]
+
+    # List of dev speakers
+    dev_spk = [
+        "fadg0",
+        "faks0",
+        "fcal1",
+        "fcmh0",
+        "fdac1",
+        "fdms0",
+        "fdrw0",
+        "fedw0",
+        "fgjd0",
+        "fjem0",
+        "fjmg0",
+        "fjsj0",
+        "fkms0",
+        "fmah0",
+        "fmml0",
+        "fnmr0",
+        "frew0",
+        "fsem0",
+        "majc0",
+        "mbdg0",
+        "mbns0",
+        "mbwm0",
+        "mcsh0",
+        "mdlf0",
+        "mdls0",
+        "mdvc0",
+        "mers0",
+        "mgjf0",
+        "mglb0",
+        "mgwt0",
+        "mjar0",
+        "mjfc0",
+        "mjsw0",
+        "mmdb1",
+        "mmdm2",
+        "mmjr0",
+        "mmwh0",
+        "mpdf0",
+        "mrcs0",
+        "mreb0",
+        "mrjm4",
+        "mrjr0",
+        "mroa0",
+        "mrtk0",
+        "mrws1",
+        "mtaa0",
+        "mtdt0",
+        "mteb0",
+        "mthc0",
+        "mwjg0",
+    ]
+
+    return dev_spk, test_spk
