@@ -1,3 +1,4 @@
+import functools
 import logging
 import math
 import random
@@ -575,5 +576,18 @@ def lens_to_mask(lens: torch.IntTensor) -> torch.Tensor:
     return mask
 
 
+def rich_exception_info(fn):
+    @functools.wraps(fn)
+    def wrapper(*args, **kwargs):
+        try:
+            return fn(*args, **kwargs)
+        except Exception as e:
+            raise type(e)(
+                f"{e}\n[extra info] When calling: {fn.__qualname__}(args={args} kwargs={kwargs})"
+            )
+
+    return wrapper
+
+
 class NonPositiveEnergyError(ValueError):
     pass
